@@ -1,20 +1,25 @@
 from django.http import Http404, HttpResponseNotFound, HttpResponseServerError
 import simplejson, logging, traceback
 
+from django.conf import settings
+
+logger = logging.getLogger("rest")
+logger.setLevel(settings.LOG_LEVEL)
+
+
 class Exception2Json():
     """
     Middleware meant to process exception found at views
     """
-
     def process_exception(self, request, exception):
-        logging.debug("middleware.Exception2Json: %s" % exception)
+        logger.error("EXCEPTION: %s" % exception)
         if isinstance(exception, Http404):
             return HttpResponseNotFound(
                 content=simplejson.dumps({"errors": [str(exception)]}),
                 content_type="application/json",)
 
-        logging.debug("middleware.Exception2Json: %s " % traceback.format_exc())
+        logger.error(traceback.format_exc())
+        msg = "Server error: %s" % exception if settings.DEBUG else "Server error"
         return HttpResponseServerError(
-            content=simplejson.dumps({"errors": ["Server error", ]}),
-            content_type="application/json",
-        )
+            content=simplejson.dumps({"errors": [msg, ]}),
+            content_type="application/json",)
